import { constructPrompt } from './prompts.js';
export class AnthropicModel {
    constructor() {
        this.config = null;
        this.baseUrl = 'https://api.anthropic.com/v1/messages';
    }
    async initialize(config) {
        if (!config.apiKey) {
            throw new Error('API key is required for Anthropic model');
        }
        const model = config.model || 'claude-3-5-sonnet-20241022';
        const maxTokens = config.maxTokens !== undefined ? config.maxTokens : 1024;
        // Validate model name
        if (typeof model !== 'string' || !model.trim()) {
            throw new Error('Invalid model name');
        }
        // Validate maxTokens - explicitly check for 0 and negative values
        if (!Number.isInteger(maxTokens) || maxTokens <= 0) {
            throw new Error('Invalid max tokens value');
        }
        this.config = {
            model,
            maxTokens,
            apiKey: config.apiKey
        };
    }
    async summarize(content, type, options) {
        if (!this.config) {
            throw new Error('Anthropic model not initialized');
        }
        const result = constructPrompt('anthropic', content, type, options);
        if (result.format !== 'anthropic') {
            throw new Error('Unexpected prompt format returned');
        }
        const prompt = result.prompt;
        try {
            let response;
            try {
                response = await fetch(this.baseUrl, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                        'anthropic-version': '2023-06-01',
                        'x-api-key': this.config.apiKey
                    },
                    body: JSON.stringify({
                        model: this.config.model,
                        max_tokens: this.config.maxTokens,
                        messages: [{
                                role: 'user',
                                content: prompt
                            }]
                    })
                });
            }
            catch (fetchError) {
                throw new Error(`Network error: ${fetchError.message}`);
            }
            if (!response.ok) {
                let errorMessage;
                try {
                    const errorData = await response.json();
                    errorMessage = errorData.error?.message || `HTTP error ${response.status}`;
                }
                catch {
                    errorMessage = `HTTP error ${response.status}`;
                }
                throw new Error(errorMessage);
            }
            let data;
            try {
                data = await response.json();
            }
            catch (parseError) {
                throw new Error(`Invalid JSON response: ${parseError.message}`);
            }
            if (!Array.isArray(data.content) || !data.content[0]?.text) {
                throw new Error('Unexpected response format from Anthropic API');
            }
            return data.content[0].text;
        }
        catch (error) {
            if (error instanceof Error) {
                throw new Error(`Anthropic summarization failed: ${error.message}`);
            }
            throw new Error('Anthropic summarization failed: Unknown error');
        }
    }
    async cleanup() {
        this.config = null;
    }
}
// Factory function to create a new Anthropic model instance
export function createAnthropicModel() {
    return new AnthropicModel();
}
